==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ColumnWidthDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnWidthDescription } from "./ColumnWidthDescription";
/**
 * @hidden
 */
var ColumnWidthDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnWidthDescriptionMetadata, _super);
    function ColumnWidthDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnWidthDescriptionMetadata.b = function (a) {
        if (ColumnWidthDescriptionMetadata.a == null) {
            ColumnWidthDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnWidthDescriptionMetadata.c(ColumnWidthDescriptionMetadata.a);
        }
        if (a.g(ColumnWidthDescriptionMetadata.a)) {
            return;
        }
        a.s(ColumnWidthDescriptionMetadata.a);
    };
    ColumnWidthDescriptionMetadata.c = function (a) {
        a.item("IsStarSized", "Boolean");
        a.item("Value", "Number:double");
        a.item("MinimumWidth", "Number:double");
    };
    ColumnWidthDescriptionMetadata.d = function (a) {
        ColumnWidthDescriptionMetadata.b(a);
        a.u("ColumnWidth", function () { return new ColumnWidthDescription(); });
        a.t("ColumnWidth", ColumnWidthDescriptionMetadata.a);
    };
    ColumnWidthDescriptionMetadata.$t = markType(ColumnWidthDescriptionMetadata, 'ColumnWidthDescriptionMetadata');
    ColumnWidthDescriptionMetadata.a = null;
    return ColumnWidthDescriptionMetadata;
}(Base));
export { ColumnWidthDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ColumnWidthDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnWidthDescription } from "./ColumnWidthDescription";
/**
 * @hidden
 */
var ColumnWidthDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnWidthDescriptionMetadata, _super);
    function ColumnWidthDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnWidthDescriptionMetadata.b = function (a) {
        if (ColumnWidthDescriptionMetadata.a == null) {
            ColumnWidthDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnWidthDescriptionMetadata.c(ColumnWidthDescriptionMetadata.a);
        }
        if (a.j(ColumnWidthDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnWidthDescriptionMetadata.a);
    };
    ColumnWidthDescriptionMetadata.c = function (a) {
        a.item("IsStarSized", "Boolean");
        a.item("Value", "Number:double");
        a.item("MinimumWidth", "Number:double");
    };
    ColumnWidthDescriptionMetadata.d = function (a) {
        ColumnWidthDescriptionMetadata.b(a);
        a.aa("ColumnWidth", function () { return new ColumnWidthDescription(); });
        a.z("ColumnWidth", ColumnWidthDescriptionMetadata.a);
    };
    ColumnWidthDescriptionMetadata.$t = markType(ColumnWidthDescriptionMetadata, 'ColumnWidthDescriptionMetadata');
    ColumnWidthDescriptionMetadata.a = null;
    return ColumnWidthDescriptionMetadata;
}(Base));
export { ColumnWidthDescriptionMetadata };
